@@ -2169,7 +2169,7 @@ int handle_ISBN13(char *data)
     //ean2isbn(data, char *isbn10_str)
 
     strcpy(appdata->EAN_text, data);
-    strcpy(appdata->title_text, "Doing ISBN13 lookup");
+    strcpy(appdata->title_text, ""); // don't tell!
     strcpy(appdata->author_text, "");
     strcpy(appdata->price_text, "");
     update_scan_window();
@@ -2187,7 +2187,7 @@ int handle_ISBN10(char *data)
     // use a web-scraper to lookup this ISBN10 code
     
     strcpy(appdata->EAN_text, data);
-    strcpy(appdata->title_text, "Doing ISBN10 lookup");
+    strcpy(appdata->title_text, ""); // don't tell!
     strcpy(appdata->author_text, "");
     strcpy(appdata->price_text, "");
     update_scan_window();
@@ -2205,7 +2205,7 @@ int handle_EAN13(char *data)
     // use a web-scraper to lookup this EAN13 code
     
     strcpy(appdata->EAN_text, data);
-    strcpy(appdata->title_text, "Doing EAN13 lookup");
+    strcpy(appdata->title_text, "");
     strcpy(appdata->author_text, "");
     strcpy(appdata->price_text, "");
     update_scan_window();
@@ -2223,7 +2223,7 @@ int handle_EAN8(char *data)
     // use a web-scraper to lookup this EAN8 code
 
     strcpy(appdata->EAN_text, data);
-    strcpy(appdata->title_text, "Doing EAN8 lookup");
+    strcpy(appdata->title_text, "");
     strcpy(appdata->author_text, "");
     strcpy(appdata->price_text, "");
     update_scan_window();
